<?php
/**
 * Blogging theme customizer sections, settings, and controls
 * @package Start_Blogging
 * @since 1.0.0
 */

// Enqueue the customizer styles for this theme
function start_blogging_custom_customize_enqueue() {
    wp_enqueue_style( 'start-blogging-customizer', get_template_directory_uri() . '/inc/customizer-style.css' );
}
if(is_admin())  add_action( 'customize_controls_enqueue_scripts', 'start_blogging_custom_customize_enqueue' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function start_blogging_custom_colour_js() {
	wp_enqueue_script( 'start-blogging-customize-controls', get_theme_file_uri( '/assets/js/customize-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'start_blogging_custom_colour_js' );

/**
 * Bind JS handlers to instantly live-preview changes.
 */
function start_blogging_customize_preview_js() {
	wp_enqueue_script( 'start-blogging-customize-preview', get_theme_file_uri( '/assets/js/customize-preview.js' ), array( 'customize-preview' ), '1.0', true );
}
add_action( 'customize_preview_init', 'start_blogging_customize_preview_js' );



 /**
 * Control type.
 * For Upsell content in the customizer
 */
if ( ! class_exists( 'Start_Blogging_Customize_Static_Text_Control' ) ){
	if ( ! class_exists( 'WP_Customize_Control' ) )
    return NULL;
		class Start_Blogging_Customize_Static_Text_Control extends WP_Customize_Control {
		public $type = 'static-text';
		public function esc_html__construct( $manager, $id, $args = array() ) {
			parent::__construct( $manager, $id, $args );
		}
		protected function render_content() {
			if ( ! empty( $this->label ) ) :
				?><span class="start-blogging-customize-control-title"><?php echo esc_html( $this->label ); ?></span><?php
			endif;
			if ( ! empty( $this->description ) ) :
				?><div class="start-blogging-description start-blogging-customize-control-description"><?php

				if( is_array( $this->description ) ) {
					echo '<p>' . implode( '</p><p>', wp_kses_post( $this->description )) . '</p>';
					
				} else {
					echo wp_kses_post( $this->description );
				}
				?>
							
			<h1><?php esc_html_e('Start Blogging Pro', 'start-blogging') ?></h1>
			
			<p><?php esc_html_e('If you decide to upgrade to the pro version of this theme, use this discount code on checkout.','start-blogging'); ?></p>	
			<div id="promotion-header"><p class="main-title"><?php esc_html_e('Upgrade to Pro (Save $5)', 'start-blogging') ?><br><?php esc_html_e('Use Code:', 'start-blogging') ?> <strong><?php esc_html_e('SAVEFIVE', 'start-blogging') ?></strong></p>
			<p><a href="https://www.bloggingthemestyles.com/wordpress-themes/start-blogging-pro/" target="_blank" class="button button-primary"><?php esc_html_e('Get the Pro - Save $5', 'start-blogging') ?></a></p></div>

			<p style="font-weight: 700;"><?php esc_html_e('Pro Features:', 'start-blogging') ?></p>
			<ul>
				<li><?php esc_html_e('&bull; 6 Blog Styles', 'start-blogging')?></li>
				<li><?php esc_html_e('&bull; 22+ Sidebars', 'start-blogging')?></li>
				<li><?php esc_html_e('&bull; 5 Page Templates', 'start-blogging')?></li>
				<li><?php esc_html_e('&bull; Blog Thumbnail Creation', 'start-blogging')?></li>
				<li><?php esc_html_e('&bull; Boxed Layouts', 'start-blogging')?></li>
				<li><?php esc_html_e('&bull; Front Page Template', 'start-blogging')?></li>
				<li><?php esc_html_e('&bull; Page Builder Ready', 'start-blogging')?></li>
				<li><?php esc_html_e('&bull; Built-in Slider', 'start-blogging')?></li>			
			</ul>
						
			<?php
			endif;
		}
	}
}

// Register the options to the WordPress customizer for this theme.
function start_blogging_customize_register( $wp_customize ) {
	
// SECTION - UPGRADE
    $wp_customize->add_section( 'start-blogging_upgrade', array(
        'title'       => esc_html__( 'Upgrade to Pro', 'start-blogging' ),
        'priority'    => 0
    ) );
	
		$wp_customize->add_setting( 'start-blogging_upgrade_pro', array(
			'default' => '',
			'sanitize_callback' => '__return_false'
		) );
		
		$wp_customize->add_control( new Start_Blogging_Customize_Static_Text_Control( $wp_customize, 'start-blogging_upgrade_pro', array(
			'label'	=> esc_html__('Get The Pro Version:','start-blogging'),
			'section'	=> 'start-blogging_upgrade',
			'description' => array('')
		) ) );	
	

    // SECTION - BASIC SETTINGS
    $wp_customize->add_section( 'start_blogging_basic_settings', array(
        'title'       => esc_html__( 'Basic Settings', 'start-blogging' ),
        'priority'    => 20
    ) );   
	
 
	 // Use excerpts for blog posts
	  $wp_customize->add_setting( 'start_blogging_use_excerpt',  array(
		  'default' => 1,
		  'sanitize_callback' => 'start_blogging_sanitize_checkbox',
		) );  
	  $wp_customize->add_control( 'start_blogging_use_excerpt', array(
		'type'     => 'checkbox',
		'label'    => __( 'Use Excerpts', 'start-blogging' ),
		'description' => __( 'Use excerpts for your blog post summaries or uncheck the box to use the standard Read More tag.', 'start-blogging' ),
		'section'  => 'start_blogging_basic_settings',
	  ) );
 
    // Excerpt size
    $wp_customize->add_setting( 'start_blogging_excerpt_size',  array(
            'sanitize_callback' => 'absint',
            'default'           => '55',
        ) );
    $wp_customize->add_control( 'start_blogging_excerpt_size', array(
        'type'        => 'number',
        'section'     => 'start_blogging_basic_settings',
        'label'       => __('Excerpt Size', 'start-blogging'),
		'description' => __('You can change the size of your blog summary excerpts with increments of 5 words.', 'start-blogging'), 
        'input_attrs' => array(
            'min'   => 10,
            'max'   => 200,
            'step'  => 5,
        ),
    ) );	
	
	// Copyright
	$wp_customize->add_setting( 'start_blogging_copyright', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wp_customize->add_control( 'start_blogging_copyright', array(
		'settings' => 'start_blogging_copyright',
		'label'    => __( 'Your Copyright Name', 'start-blogging' ),
		'section'  => 'start_blogging_basic_settings',		
		'type'     => 'text',
	) );   
  
  
// Add to the colour section
  	 
  
// CUSTOM COLOURS.

	$wp_customize->add_setting( 'colorscheme', array(
		'default'           => 'default',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'start_blogging_sanitize_colorscheme',
	) );

	$wp_customize->add_setting( 'colorscheme_hue', array(
		'default'           => 44,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'absint', // The hue is stored as a positive integer.
	) );

	$wp_customize->add_control( 'colorscheme', array(
		'type'    => 'radio',
		'label'    => __( 'Color Scheme', 'start-blogging' ),
		'choices'  => array(
			'default'  => __( 'Default', 'start-blogging' ),
			'custom' => __( 'Custom', 'start-blogging' ),
		),
		'section'  => 'colors',
		'priority' => 5,
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'colorscheme_hue', array(
		'mode' => 'hue',
		'section'  => 'colors',
		'priority' => 6,
	) ) );  
  
}

add_action( 'customize_register', 'start_blogging_customize_register' );

// SANITIZATION
//Checkboxes
if ( ! function_exists( 'start_blogging_sanitize_checkbox' ) ) :
	function start_blogging_sanitize_checkbox( $input ) {
		return ( isset( $input ) && true === (bool) $input ? true : false );
	}
endif;

/*
 * Sanitize the colorscheme.
 * @param string $input Color scheme.
 */
function start_blogging_sanitize_colorscheme( $input ) {
	$valid = array( 'default', 'custom' );

	if ( in_array( $input, $valid, true ) ) {
		return $input;
	}

	return 'default';
}